# PATATUNE Reference

This reference manual details functions, modules, and objects included in PATATUNE, describing what they are and what they do.

<br>

::: patatune
    options:
        show_root_heading: false
        show_root_toc_entry: false
